[gimp] plug-ins: eek, twain calls gimp_main() directly



commit fd555144167d82bd112fc6d882756c8ad76f1e28
Author: Michael Natterer <mitch gimp org>
Date:   Fri Aug 9 00:50:32 2019 +0200

    plug-ins: eek, twain calls gimp_main() directly
    
    Make it call gimp_main_legacy() instead.

 plug-ins/twain/tw_win.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/plug-ins/twain/tw_win.c b/plug-ins/twain/tw_win.c
index 726a45f55e..615da6cd16 100644
--- a/plug-ins/twain/tw_win.c
+++ b/plug-ins/twain/tw_win.c
@@ -298,10 +298,10 @@ WinMain(HINSTANCE hInstance,
 #endif /* _DEBUG */
 
   /*
    * Now, call gimp_main... This is what the MAIN() macro
    * would usually do.
    */
-  return gimp_main(&PLUG_IN_INFO, __argc, __argv);
+  return gimp_main_legacy(&PLUG_IN_INFO, __argc, __argv);
 }
 
 /*
@@ -319,10 +319,10 @@ int main (int argc, char *argv[])
 #endif /* _DEBUG */
 
   /*
    * Now, call gimp_main... This is what the MAIN() macro
    * would usually do.
    */
-  return gimp_main(&PLUG_IN_INFO, __argc, __argv);
+  return gimp_main_legacy(&PLUG_IN_INFO, __argc, __argv);
 }
 
 /*
@@ -298,10 +298,10 @@ WinMain(HINSTANCE hInstance,
 
   /*
-   * Now, call gimp_main... This is what the MAIN() macro
+   * Now, call gimp_main_legacy... This is what the MAIN() macro
    * would usually do.
    */
@@ -319,10 +319,10 @@ int main (int argc, char *argv[])
 
   /*
-   * Now, call gimp_main... This is what the MAIN() macro
+   * Now, call gimp_main_legacy... This is what the MAIN() macro
    * would usually do.
    */


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]